@@ -3,7 +3,9 @@ Twitch API access.
 """
 
 import httpx
+import json
 
+from typing import Dict
 from twitchdl import CLIENT_ID
 from twitchdl.exceptions import ConsoleError
 
@@ -14,21 +16,6 @@ class GQLError(Exception):
         self.errors = errors
 
 
-def authenticated_get(url, params={}, headers={}):
-    headers['Client-ID'] = CLIENT_ID
-
-    response = httpx.get(url, params=params, headers=headers)
-    if 400 <= response.status_code < 500:
-        data = response.json()
-        # TODO: this does not look nice in the console since data["message"]
-        # can contain a JSON encoded object.
-        raise ConsoleError(data["message"])
-
-    response.raise_for_status()
-
-    return response
-
-
 def authenticated_post(url, data=None, json=None, headers={}):
     headers['Client-ID'] = CLIENT_ID
 
@@ -52,7 +39,7 @@ def gql_post(query):
     return response
 
 
-def gql_query(query, headers={}):
+def gql_query(query: str, headers: Dict[str, str] = {}):
     url = "https://gql.twitch.tv/gql"
     response = authenticated_post(url, json={"query": query}, headers=headers).json()
 
@@ -374,3 +361,32 @@ def get_game_id(name):
     game = response["data"]["game"]
     if game:
         return game["id"]
+
+
+def get_video_chapters(video_id):
+    query = {
+        "operationName": "VideoPlayer_ChapterSelectButtonVideo",
+        "variables":
+        {
+            "includePrivate": False,
+            "videoID": video_id
+        },
+        "extensions":
+        {
+            "persistedQuery":
+            {
+                "version": 1,
+                "sha256Hash": "8d2793384aac3773beab5e59bd5d6f585aedb923d292800119e03d40cd0f9b41"
+            }
+        }
+    }
+
+    response = gql_post(json.dumps(query))
+    return list(_chapter_nodes(response["data"]["video"]["moments"]))
+
+
+def _chapter_nodes(collection):
+    for edge in collection["edges"]:
+        node = edge["node"]
+        del node["moments"]
+        yield node
